@@ -3,9 +3,9 @@ import functools
 import logging
 import uuid
 
-import msgpack
 from redis import asyncio as aioredis
 
+from .serializers import registry
 from .utils import (
     _close_redis,
     _consistent_hash,
@@ -25,10 +25,21 @@ async def _async_proxy(obj, name, *args, **kwargs):
 
 
 class RedisPubSubChannelLayer:
-    def __init__(self, *args, **kwargs) -> None:
+    def __init__(
+        self,
+        *args,
+        symmetric_encryption_keys=None,
+        serializer_format="msgpack",
+        **kwargs,
+    ) -> None:
         self._args = args
         self._kwargs = kwargs
         self._layers = {}
+        # serialization
+        self._serializer = registry.get_serializer(
+            serializer_format,
+            symmetric_encryption_keys=symmetric_encryption_keys,
+        )
 
     def __getattr__(self, name):
         if name in (
@@ -48,13 +59,13 @@ class RedisPubSubChannelLayer:
         """
         Serializes message to a byte string.
         """
-        return msgpack.packb(message)
+        return self._serializer.serialize(message)
 
     def deserialize(self, message):
         """
         Deserializes from a byte string.
         """
-        return msgpack.unpackb(message)
+        return self._serializer.deserialize(message)
 
     def _get_layer(self):
         loop = asyncio.get_running_loop()
@@ -167,7 +178,7 @@ class RedisPubSubLoopLayer:
             # We assume here that the reason we are cancelled is because the consumer
             # is exiting, therefore we need to cleanup by unsubscribe below. Indeed,
             # currently the way that Django Channels works, this is a safe assumption.
-            # In the future, Dajngo Channels could change to call a *new* method that
+            # In the future, Django Channels could change to call a *new* method that
             # would serve as the antithesis of `new_channel()`; this new method might
             # be named `delete_channel()`. If that were the case, we would do the
             # following cleanup from that new `delete_channel()` method, but, since
