@@ -61,7 +61,8 @@ async def test_send_receive(channel_layer):
     assert message["text"] == "Ahoy-hoy!"
 
 
-def test_send_receive_sync(channel_layer, event_loop):
+def test_send_receive_sync(channel_layer):
+    event_loop = asyncio.new_event_loop()
     _await = event_loop.run_until_complete
     channel = _await(channel_layer.new_channel())
     async_to_sync(channel_layer.send, force_new_loop=True)(
@@ -70,6 +71,7 @@ def test_send_receive_sync(channel_layer, event_loop):
     message = _await(channel_layer.receive(channel))
     assert message["type"] == "test.message"
     assert message["text"] == "Ahoy-hoy!"
+    event_loop.close()
 
 
 @pytest.mark.asyncio
@@ -86,7 +88,8 @@ async def test_multi_send_receive(channel_layer):
     assert (await channel_layer.receive(channel))["type"] == "message.3"
 
 
-def test_multi_send_receive_sync(channel_layer, event_loop):
+def test_multi_send_receive_sync(channel_layer):
+    event_loop = asyncio.new_event_loop()
     _await = event_loop.run_until_complete
     channel = _await(channel_layer.new_channel())
     send = async_to_sync(channel_layer.send)
@@ -96,6 +99,7 @@ def test_multi_send_receive_sync(channel_layer, event_loop):
     assert _await(channel_layer.receive(channel))["type"] == "message.1"
     assert _await(channel_layer.receive(channel))["type"] == "message.2"
     assert _await(channel_layer.receive(channel))["type"] == "message.3"
+    event_loop.close()
 
 
 @pytest.mark.asyncio
